==> qt-creator-opensource-src-4.1.0.zip: qt-creator-opensource-src-4.1.0/src/plugins/projectexplorer/panelswidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "projectexplorer_export.h"

#include <QScrollArea>

QT_BEGIN_NAMESPACE
class QGridLayout;
QT_END_NAMESPACE

namespace ProjectExplorer {
class PropertiesPanel;

class PROJECTEXPLORER_EXPORT PanelsWidget : public QScrollArea
{
    Q_OBJECT
public:
    explicit PanelsWidget(QWidget *parent = nullptr);
    ~PanelsWidget() override;

    // Adds a widget
    void addPropertiesPanel(PropertiesPanel *panel);

private:
    void addPanelWidget(PropertiesPanel *panel, int row);

    QList<PropertiesPanel *> m_panels;
    QGridLayout *m_layout;
    QWidget *m_root;
};

} // namespace ProjectExplorer

==> qt-creator-opensource-src-4.2.1.zip: qt-creator-opensource-src-4.2.1/src/plugins/projectexplorer/panelswidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "projectexplorer_export.h"

#include <QScrollArea>

QT_BEGIN_NAMESPACE
class QGridLayout;
class QIcon;
QT_END_NAMESPACE

namespace ProjectExplorer {

class PROJECTEXPLORER_EXPORT PanelsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit PanelsWidget(QWidget *parent = nullptr);
    ~PanelsWidget() override;

    void addPropertiesPanel(const QString &displayName, const QIcon &icon,
                            QWidget *widget);

private:
    QGridLayout *m_layout;
    QScrollArea *m_scroller;
    QWidget *m_root;
};

} // namespace ProjectExplorer
